@@ -33,8 +33,6 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #ifndef XKB_IN_SERVER
 
 #include <stdio.h>
-#define NEED_REPLIES
-#define NEED_EVENTS
 #include "Xlibint.h"
 #include <X11/extensions/XKBproto.h>
 #include <X11/keysym.h>
@@ -44,8 +42,6 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 #include <stdio.h>
 #include <X11/X.h>
-#define	NEED_EVENTS
-#define	NEED_REPLIES
 #include <X11/Xproto.h>
 #include "misc.h"
 #include "inputstr.h"
